==> sylpheed-claws-gtk2_2.1.1.orig.tar.gz: sylpheed-claws-gtk2-2.1.1/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Ho Vit Dinh <hoa@users.sf.net>",
"Werner Koch <wk@gnupg.org>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <mones@users.sf.net>",
"Colin Leroy <colinleroy@users.sf.net>",
"Paul Mangan <twb@users.sf.net>",
"Martin Schaaf <mascha1@users.sf.net>",
"wwp <wwp@users.sf.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Carsten Schurig",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] Tim <timbrain@post.cz>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <twb@users.sf.net>",
"[el] Stavros Giannouris <stavrosg2002@freemail.gr>",
"[es] Ricardo Mones Lastra <mones@users.sf.net>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Fabien Vantard <fzzzzz@gmail.com>",
"[hr] Dragan <drleskov@inet.hr>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] Rui Hirokawa <rui_hirokawa@ybb.ne.jp>",
"[ko] SungHyun Nam <namsh@kldp.org>",
"[nb] Geir Helland <pjallabais@users.sf.net>",
"[nl] Tim Dijkstra <tim@famdijkstra.org>",
"[pl] Emilian Nowak <eminowbl@posejdon.wpk.p.lodz.pl>",
"[pl] Quar <Quar@sylpheed.quar.org>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[ru] Pavlo Bohmat <bohm@ukr.net>",
"[sk] Andrej Kacian <andrej@kacian.sk>",
"[sr] Aleksandar Urosevic <urke@users.sf.net>",
"[sv] Anders Trobck <sylpheed@troback.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
"[zh_TW] Wei-Lun Chao <chaoweilun@pcmail.com.tw>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"Ricardo Mones Lastra <mones@users.sf.net>",
"Colin Leroy <colinleroy@users.sf.net>",
"Paul Mangan <twb@users.sf.net>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Eugene Brevdo",
"Andr Filipe de Assuno e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Felix Eckhofer",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Xavier FACQ",
"Bob Forsman",
"Matthias Frste",
"Stoyan Genov",
"Thomas Gilgin",
"Thierry Godefroy",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Ricardo Mones Lastra",
"Jean-Yves Lefort",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"James Noyes",
"Jens Oberender",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Pawel Pkala",
"Don Quijote",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skytt",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"shigeri",
"Shimamoto \"Neko\" Tatsuya",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Tsutsui",
"Aleksandar Urosevic",
"Fabien Vantard",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gl Zoltn",
"Marien Zwart",
"Martin Zwickel",
"Alexey Illarionov",
NULL
};

==> sylpheed-claws-gtk2_2.5.0~rc3.orig.tar.gz: sylpheed-claws-gtk2-2.5.0~rc3/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Ho Vit Dinh <hoa@users.sf.net>",
"Werner Koch <wk@gnupg.org>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <claws@thewildbeast.co.uk>",
"Martin Schaaf <mascha1@users.sf.net>",
"wwp <wwp@users.sf.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Carsten Schurig",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] Tim <timbrain@post.cz>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <claws@thewildbeast.co.uk>",
"[el] Stavros Giannouris <stavrosg2002@freemail.gr>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Fabien Vantard <fzzzzz@gmail.com>",
"[hr] Dragan <drleskov@inet.hr>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] Rui Hirokawa <rui_hirokawa@ybb.ne.jp>",
"[ko] SungHyun Nam <namsh@kldp.org>",
"[nb] Geir Helland <pjallabais@users.sf.net>",
"[nl] Tim Dijkstra <tim@famdijkstra.org>",
"[pl] Emilian Nowak <eminowbl@posejdon.wpk.p.lodz.pl>",
"[pl] Quar <Quar@sylpheed.quar.org>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[ru] Pavlo Bohmat <bohm@ukr.net>",
"[sk] Andrej Kacian <andrej@kacian.sk>",
"[sr] Aleksandar Urosevic <urke@users.sf.net>",
"[sv] Anders Trobck <sylpheed@troback.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
"[zh_TW] Wei-Lun Chao <chaoweilun@pcmail.com.tw>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <claws@thewildbeast.co.uk>",
"     wwp <wwp@users.sf.net>",
"[fr] Colin Leroy <colin@colino.net>",
"     wwp <wwp@users.sf.net>",
"[pl] Pawel Pekala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Eugene Brevdo",
"Andr Filipe de Assuno e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Frste",
"Stoyan Genov",
"Thomas Gilgin",
"Thierry Godefroy",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Ricardo Mones Lastra",
"Jean-Yves Lefort",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"James Noyes",
"Jens Oberender",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Pawel Pkala",
"Don Quijote",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skytt",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"shigeri",
"Shimamoto \"Neko\" Tatsuya",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Tsutsui",
"Aleksandar Urosevic",
"Fabien Vantard",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gl Zoltn",
"Marien Zwart",
"Martin Zwickel",
NULL
};
